<?php

namespace MGS\Blog\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Store\Model\StoreManagerInterface;
use Magento\Store\Model\ScopeInterface;
use Magento\Framework\UrlInterface;
use Magento\Framework\App\ObjectManager;

class Data extends AbstractHelper
{
    protected $storeManager;

    public function __construct(
        Context $context,
        StoreManagerInterface $storeManager
    )
    {
        $this->storeManager = $storeManager;
        parent::__construct($context);
    }

    public function getConfig($key, $store = null)
    {
        if ($store == null || $store == '') {
            $store = $this->storeManager->getStore()->getId();
        }
        $store = $this->storeManager->getStore($store);
        $config = $this->scopeConfig->getValue(
            'blog/' . $key,
            ScopeInterface::SCOPE_STORE,
            $store);
        return $config;
    }

    public function getBaseMediaUrl()
    {
        return $this->storeManager->getStore()->getBaseUrl(UrlInterface::URL_TYPE_MEDIA);
    }

    public function getRoute()
    {
        $route = $this->getConfig('general_settings/route');
        if ($this->getConfig('general_settings/route') == '') {
            $route = 'blog';
        }
        return $this->storeManager->getStore()->getBaseUrl() . $route;
    }

    public function getTagUrl($tag)
    {
        $route = $this->getConfig('general_settings/route');
        if ($this->getConfig('general_settings/route') == '') {
            $route = 'blog';
        }
        return $this->storeManager->getStore()->getBaseUrl() . $route . '/tag/' . urlencode($tag);
    }

    public function convertSlashes($tag, $direction = 'back')
    {
        if ($direction == 'forward') {
            $tag = preg_replace("#/#is", "&#47;", $tag);
            $tag = preg_replace("#\\\#is", "&#92;", $tag);
            return $tag;
        }
        $tag = str_replace("&#47;", "/", $tag);
        $tag = str_replace("&#92;", "\\", $tag);
        return $tag;
    }

    public function checkLoggedIn()
    {
        $objectManager = ObjectManager::getInstance();
        return $objectManager->get('Magento\Customer\Model\Session')->isLoggedIn();
    }
	
    public function getThumbnailPost($post)
    {	
		$html = "";
		$store = $this->storeManager->getStore()->getCode();
		if($post->getThumbType() == "video"){
			if($post->getVideoThumbId() != ""){
				if($post->getVideoThumbType() == "youtube"){
					$video_url = 'https://www.youtube.com/embed/'.$post->getVideoThumbId();
				}else {
					$video_url = 'https://player.vimeo.com/video/'.$post->getVideoThumbId();
				}
				$html .= '<div class="video-responsive">';
				$html .= '<iframe width="1024" height="768" src="'.$video_url.'" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>';
				$html .= '</div>';
			}
		}else {
			if($post->getThumbnailUrl() == ""){
				$html = "";
			}else {
				if($store){
					$html .= '<a class="post-title-link" title="'.$post->getTitle().'" href="'.$post->getPostUrlWithNoCategory().'?___store='.$store.'">';
				}else{
					$html .= '<a class="post-title-link" title="'.$post->getTitle().'" href="'.$post->getPostUrlWithNoCategory().'">';
				}				
				$html .= '<img class="img-responsive" alt="'.$post->getTitle().'" src="'.$post->getThumbnailUrl().'">';
				$html .= '</a>';  
			}
		}
        return $html;
    }
	
	
    public function getImagePost($post)
    {	
		$html = "";
		if($post->getImageType() == "video"){
			if($post->getVideoBigId() != ""){
				if($post->getVideoBigType() == "youtube"){
					$video_url = 'https://www.youtube.com/embed/'.$post->getVideoBigId();
				}else {
					$video_url = 'https://player.vimeo.com/video/'.$post->getVideoBigId();
				}
				$html .= '<div class="video-responsive">';
				$html .= '<iframe width="1024" height="768" src="'.$video_url.'" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>';
				$html .= '</div>';
			}
		}else {
			if($post->getImageUrl() == ""){
				$html = "";
			}else {
				$html .= '<img class="img-responsive" alt="'.$post->getTitle().'" src="'.$post->getImageUrl().'">';
			}
		}
        return $html;
    }
	
	public function getClassColMasonry()
    {	
		$html = "col-md-4 col-sm-6 col-xs-12";
		$cf_column = $this->getConfig('general_settings/number_column');
		if($cf_column == 2){
			$html = "col-md-6 col-sm-6 col-xs-12";
		}
		if($cf_column == 3){
			$html = "col-md-4 col-sm-6 col-xs-12";
		}
		if($cf_column == 4){
			$html = "col-md-3 col-sm-6 col-xs-12";
		}
        return $html;
    }
	
	public function getCateClassColMasonry()
    {	
		$html = "col-md-4 col-sm-6 col-xs-12";
		$cf_column = $this->getConfig('category_settings/cate_number_column');
		if($cf_column == 2){
			$html = "col-md-6 col-sm-6 col-xs-12";
		}
		if($cf_column == 3){
			$html = "col-md-4 col-sm-6 col-xs-12";
		}
		if($cf_column == 4){
			$html = "col-md-3 col-sm-6 col-xs-12";
		}
        return $html;
    }
	
	public function getThumbnailImgVideoPost($post)
    {	
		if($post->getThumbType() == "video"){
			if($post->getVideoThumbId() != ""){
				if($post->getVideoThumbType() == "youtube"){
					return 'http://img.youtube.com/vi/'.$post->getVideoThumbId().'/hqdefault.jpg';
				}else {
					$info = 'thumbnail_medium';
					$ch = curl_init();
					curl_setopt($ch, CURLOPT_URL, 'vimeo.com/api/v2/video/'.$post->getVideoThumbId().'.php');
					curl_setopt($ch, CURLOPT_HEADER, 0);
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
					curl_setopt($ch, CURLOPT_TIMEOUT, 10);
					$output = unserialize(curl_exec($ch));
					$output = $output[0][$info];
					curl_close($ch);
					return $output;
				}
			}
			
		}
		return;
    }
}
