<?php
/**
 * Copyright © 2015 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace MGS\Mpanel\Helper;

/**
 * Contact base helper
 */
class Data extends \Magento\Framework\App\Helper\AbstractHelper
{
	protected $_scopeConfig;
	
	protected $_storeManager;
	
	protected $_date;
	
	protected $_url;
	
	public function __construct(
		\Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
		\Magento\Store\Model\StoreManagerInterface $storeManager,
		\Magento\Framework\Stdlib\DateTime\DateTime $date,
		\Magento\Catalog\Model\Category $category,
		\Magento\Framework\ObjectManagerInterface $objectManager,
		\Magento\Framework\Url $url,
		\Magento\Catalog\Model\Design $catalogDesign
	) {
		$this->_scopeConfig = $scopeConfig;
		$this->_storeManager = $storeManager;
		$this->_date = $date;
		$this->_category = $category;
		$this->_objectManager = $objectManager;
		$this->_url = $url;
		$this->_catalogDesign = $catalogDesign;
	}
	
	public function getStore(){
		return $this->_storeManager->getStore();
	}
	
	public function getStoreConfig($node, $storeId = NULL){
		if($storeId != NULL){
			return $this->_scopeConfig->getValue($node, \Magento\Store\Model\ScopeInterface::SCOPE_STORE, $storeId);
		}
		return $this->_scopeConfig->getValue($node, \Magento\Store\Model\ScopeInterface::SCOPE_STORE, $this->getStore()->getId());
	}
	/* Get Categories */
	
	public function getModel($model)
	{
		return $this->_objectManager->create($model);
	}
	
	public function getCurrentlySelectedCategoryId()
	{
		$params = $this->getModel('Magento\Framework\App\Request\Http')->getParams();
		if (isset($params['cat'])) {
			return $params['cat'];
		}
		return '';
	}
	
	public function getStoreViewId()
	{
		return $this->_storeManager->getStore()->getId();
	}
	
	public function getCategories()
	{
		$rootCategoryId = $this->_storeManager->getStore()->getRootCategoryId();
		$categoriesArray = $this->_category
			->getCollection()
			->setStoreId($this->_storeManager->getStore()->getId())
			->addAttributeToSelect('*')
			->addAttributeToFilter('is_active', 1)
			->addAttributeToFilter('include_in_menu', 1)
			->addAttributeToFilter('path', array('like' => "1/{$rootCategoryId}/%"))
			->addAttributeToSort('path', 'asc')
			->load()
			->toArray();
		$categories = array();
		if(isset($categoriesArray['items'])){
			foreach ($categoriesArray['items'] as $categoryId => $category) {
				if (isset($category['name'])) {
					$categories[] = array(
						'label' => $category['name'],
						'level' => $category['level'],
						'value' => $category['entity_id']
					);
				}
			}
		}else {
			foreach ($categoriesArray as $categoryId => $category) {
				if (isset($category['name'])) {
					$categories[] = array(
						'label' => $category['name'],
						'level' => $category['level'],
						'value' => $category['entity_id']
					);
				}
			}
		}
		return $categories;
	}
	
	public function getThemeSettings(){
		return [
			'catalog'=> 
			[
				'per_row' => $this->getStoreConfig('mpanel/catalog/product_per_row'),
				'featured' => $this->getStoreConfig('mpanel/catalog/featured'),
				'hot' => $this->getStoreConfig('mpanel/catalog/hot'),
				'ratio' => $this->getStoreConfig('mpanel/catalog/picture_ratio'),
				'new_label' => $this->getStoreConfig('mpanel/catalog/new_label'),
				'sale_label' => $this->getStoreConfig('mpanel/catalog/sale_label'),
				'preload' => $this->getStoreConfig('mpanel/catalog/preload'),
				'wishlist_button' => $this->getStoreConfig('mpanel/catalog/wishlist_button'),
				'compare_button' => $this->getStoreConfig('mpanel/catalog/compare_button')
			],
			'product_details'=> 
			[
				'sku' => $this->getStoreConfig('mpanel/product_details/sku'),
				'reviews_summary' => $this->getStoreConfig('mpanel/product_details/reviews_summary'),
				'wishlist' => $this->getStoreConfig('mpanel/product_details/wishlist'),
				'compare' => $this->getStoreConfig('mpanel/product_details/compare'),
				'preload' => $this->getStoreConfig('mpanel/product_details/preload'),
				'short_description' => $this->getStoreConfig('mpanel/product_details/short_description'),
				'upsell_products' => $this->getStoreConfig('mpanel/product_details/upsell_products')
			],
			'product_tabs'=> 
			[
				'show_description' => $this->getStoreConfig('mpanel/product_tabs/show_description'),
				'show_additional' => $this->getStoreConfig('mpanel/product_tabs/show_additional'),
				'show_reviews' => $this->getStoreConfig('mpanel/product_tabs/show_reviews'),
				'show_product_tag_list' => $this->getStoreConfig('mpanel/product_tabs/show_product_tag_list')
			],
			'contact_google_map'=> 
			[
				'contact_page_type' => $this->getStoreConfig('mpanel/contact_google_map/contact_page_type'),
				'display_google_map' => $this->getStoreConfig('mpanel/contact_google_map/display_google_map'),
				'api_key' => $this->getStoreConfig('mpanel/contact_google_map/api_key'),
				'address_google_map' => $this->getStoreConfig('mpanel/contact_google_map/address_google_map'),
				'html_google_map' => $this->getStoreConfig('mpanel/contact_google_map/html_google_map'),
				'pin_google_map' => $this->getStoreConfig('mpanel/contact_google_map/pin_google_map')
			],
			'banner_slider'=> 
			[
				'slider_tyle' => $this->getStoreConfig('mgstheme/banner_slider/slider_tyle'),
				'id_reslider' => $this->getStoreConfig('mgstheme/banner_slider/id_reslider'),
				'identifier_block' => $this->getStoreConfig('mgstheme/banner_slider/identifier_block'),
				'banner_owl_auto' => $this->getStoreConfig('mgstheme/banner_slider/banner_owl_auto'),
				'banner_owl_speed' => $this->getStoreConfig('mgstheme/banner_slider/banner_owl_speed'),
				'banner_owl_loop' => $this->getStoreConfig('mgstheme/banner_slider/banner_owl_loop'),
				'banner_owl_nav' => $this->getStoreConfig('mgstheme/banner_slider/banner_owl_nav'),
				'banner_owl_dot' => $this->getStoreConfig('mgstheme/banner_slider/banner_owl_dot')
			],
			'general'=>
			[
				'version_product' => $this->getStoreConfig('mgstheme/general/version_product')
			]
		];
	}
	
	/* Get col for responsive */
	public function getColClass($perrow = NULL){
		if(!$perrow){
			$settings = $this->getThemeSettings();
			$perrow = $settings['catalog']['per_row'];
		}
		
		switch($perrow){
			case 2:
				return 'col-lg-6 col-md-6 col-sm-6 col-xs-6 col-xss-12';
				break;
			case 3:
				return 'col-lg-4 col-md-4 col-sm-4 col-xs-6 col-xss-12';
				break;
			case 4:
				return 'col-lg-3 col-md-3 col-sm-4 col-xs-6 col-xss-12';
				break;
			case 5:
				return 'col-lg-custom-5 col-md-3 col-sm-4 col-xs-12 col-xss-12';
				break;
			case 6:
				return 'col-lg-2 col-md-2 col-sm-4 col-xs-6 col-xss-12';
				break;
		}
		return;
	}
	/* Get class clear left */
	public function getClearClass($perrow = NULL, $nb_item){
		if(!$perrow){
			$settings = $this->getThemeSettings();
			$perrow = $settings['catalog']['per_row'];
		}
		$clearClass = '';
		switch($perrow){
			case 2:
				if($nb_item % 2 == 1){
					$clearClass.= " first-row-item first-sm-item first-xs-item";
				}
				return $clearClass;
				break;
			case 3:
				if($nb_item % 3 == 1){
					$clearClass.= " first-row-item first-sm-item ";
				}
				if($nb_item % 2 == 1){
					$clearClass.= " first-xs-item";
				}
				return $clearClass;
				break;
			case 4:
				if($nb_item % 4 == 1){
					$clearClass.= " first-row-item";
				}
				if($nb_item % 3 == 1){
					$clearClass.= " first-sm-item ";
				}
				if($nb_item % 2 == 1){
					$clearClass.= " first-xs-item";
				}
				return $clearClass;
				break;
			case 5:
				if($nb_item % 5 == 1){
					$clearClass.= " first-lg-item";
				}
				if($nb_item % 4 == 1){
					$clearClass.= " first-md-item";
				}
				if($nb_item % 3 == 1){
					$clearClass.= " first-sm-item";
				}
				if($nb_item % 2 == 1){
					$clearClass.= " first-xs-item";
				}
				return $clearClass;
				break;
			case 6:
				if($nb_item % 6 == 1){
					$clearClass.= " first-row-item";
				}
				if($nb_item % 3 == 1){
					$clearClass.= " first-sm-item ";
				}
				if($nb_item % 2 == 1){
					$clearClass.= " first-xs-item";
				}
				return $clearClass;
				break;
		}
	}
	
	/* Get product image size */
	public function getImageSize(){
		$ratio = $this->getStoreConfig('mpanel/catalog/picture_ratio');
		$maxWidth = $this->getStoreConfig('mpanel/catalog/max_width_image');
		$result = [];
        switch ($ratio) {
            // 1/1 Square
            case 1:
                $result = array('width' => round($maxWidth), 'height' => round($maxWidth));
                break;
            // 1/2 Portrait
            case 2:
                $result = array('width' => round($maxWidth), 'height' => round($maxWidth*2));
                break;
            // 2/3 Portrait
            case 3:
                $result = array('width' => round($maxWidth), 'height' => round(($maxWidth * 1.5)));
                break;
            // 3/4 Portrait
            case 4:
                $result = array('width' => round($maxWidth), 'height' => round(($maxWidth * 4) / 3));
                break;
            // 2/1 Landscape
            case 5:
                $result = array('width' => round($maxWidth), 'height' => round($maxWidth/2));
                break;
            // 3/2 Landscape
            case 6:
                $result = array('width' => round($maxWidth), 'height' => round(($maxWidth*2) / 3));
                break;
            // 4/3 Landscape
            case 7:
                $result = array('width' => round($maxWidth), 'height' => round(($maxWidth*3) / 4));
                break;
        }

        return $result;
	}
	
	/* Get product image size for product details page*/
	public function getImageSizeForDetails() {
		$ratio = $this->getStoreConfig('mpanel/catalog/picture_ratio');
		$maxWidth = $this->getStoreConfig('mpanel/catalog/max_width_image_detail');
        $result = [];
        switch ($ratio) {
            // 1/1 Square
            case 1:
                $result = array('width' => round($maxWidth), 'height' => round($maxWidth));
                break;
            // 1/2 Portrait
            case 2:
                $result = array('width' => round($maxWidth), 'height' => round($maxWidth*2));
                break;
            // 2/3 Portrait
            case 3:
                $result = array('width' => round($maxWidth), 'height' => round(($maxWidth * 1.5)));
                break;
            // 3/4 Portrait
            case 4:
                $result = array('width' => round($maxWidth), 'height' => round(($maxWidth * 4) / 3));
                break;
            // 2/1 Landscape
            case 5:
                $result = array('width' => round($maxWidth), 'height' => round($maxWidth/2));
                break;
            // 3/2 Landscape
            case 6:
                $result = array('width' => round($maxWidth), 'height' => round(($maxWidth*2) / 3));
                break;
            // 4/3 Landscape
            case 7:
                $result = array('width' => round($maxWidth), 'height' => round(($maxWidth*3) / 4));
                break;
        }

        return $result;
    }
	
	public function getImageMinSize() {
        $ratio = $this->getStoreConfig('mpanel/catalog/picture_ratio');
        $result = [];
        switch ($ratio) {
            // 1/1 Square
            case 1:
                $result = array('width' => 80, 'height' => 80);
                break;
            // 1/2 Portrait
            case 2:
                $result = array('width' => 80, 'height' => 160);
                break;
            // 2/3 Portrait
            case 3:
                $result = array('width' => 80, 'height' => 120);
                break;
            // 3/4 Portrait
            case 4:
                $result = array('width' => 80, 'height' => 107);
                break;
            // 2/1 Landscape
            case 5:
                $result = array('width' => 80, 'height' => 40);
                break;
            // 3/2 Landscape
            case 6:
                $result = array('width' => 80, 'height' => 53);
                break;
            // 4/3 Landscape
            case 7:
                $result = array('width' => 80, 'height' => 60);
                break;
        }

        return $result;
    }
	
	public function getProductLabel($product){
		$html = '';
		$newLabel = $this->getStoreConfig('mpanel/catalog/new_label');
        $saleLabel = "";
		if($this->getStoreConfig('mpanel/catalog/sale_label') == 1){
			$saleLabel = 1;
		}

		// Sale label
		$price = $product->getPrice();
		$finalPrice = $product->getFinalPrice();
		$save = $price - $finalPrice;
		if(($finalPrice<$price) && ($saleLabel!='')){
			$percent = round(($save * 100) / $price);
			$html .= '<span class="product-label sale-label"><span>-'.$percent.'%</span></span>';
		}
		
		// New label
		$now = $this->_date->gmtDate();
		$dateTimeFormat = \Magento\Framework\Stdlib\DateTime::DATETIME_PHP_FORMAT;
		$newFromDate = $product->getNewsFromDate();
        $newFromDate = date($dateTimeFormat, strtotime($newFromDate));
        $newToDate = $product->getNewsToDate();
        $newToDate = date($dateTimeFormat, strtotime($newToDate));
		if ((!(empty($newToDate) && empty($newFromDate)) && ($newFromDate < $now || empty($newFromDate)) && ($newToDate > $now || empty($newToDate)) && ($newLabel != '')) || ((empty($newToDate) && ($newFromDate < $now)) && ($newLabel != ''))) {
			$html.='<span class="product-label new-label"><span>'.$newLabel.'</span></span>';
		}
		
		return $html;
	}
	
	public function getUrlBuilder(){
		return $this->_url;
	}
	
	public function getCssUrl(){
		return $this->_url->getUrl('mpanel/index/css',['store'=>$this->getStore()->getId()]);
	}
	
	public function getFonts() {
        return [
            ['css-name' => 'Lato', 'font-name' => __('Lato')],
            ['css-name' => 'Open+Sans', 'font-name' => __('Open Sans')],
            ['css-name' => 'Roboto', 'font-name' => __('Roboto')],
            ['css-name' => 'Roboto Slab', 'font-name' => __('Roboto Slab')],
            ['css-name' => 'Oswald', 'font-name' => __('Oswald')],
            ['css-name' => 'Source+Sans+Pro', 'font-name' => __('Source Sans Pro')],
            ['css-name' => 'PT+Sans', 'font-name' => __('PT Sans')],
            ['css-name' => 'PT+Serif', 'font-name' => __('PT Serif')],
            ['css-name' => 'Droid+Serif', 'font-name' => __('Droid Serif')],
            ['css-name' => 'Josefin+Slab', 'font-name' => __('Josefin Slab')],
            ['css-name' => 'Montserrat', 'font-name' => __('Montserrat')],
            ['css-name' => 'Ubuntu', 'font-name' => __('Ubuntu')],
            ['css-name' => 'Titillium+Web', 'font-name' => __('Titillium Web')],
            ['css-name' => 'Noto+Sans', 'font-name' => __('Noto Sans')],
            ['css-name' => 'Lora', 'font-name' => __('Lora')],
            ['css-name' => 'Playfair+Display', 'font-name' => __('Playfair Display')],
            ['css-name' => 'Bree+Serif', 'font-name' => __('Bree Serif')],
            ['css-name' => 'Vollkorn', 'font-name' => __('Vollkorn')],
            ['css-name' => 'Alegreya', 'font-name' => __('Alegreya')],
            ['css-name' => 'Noto+Serif', 'font-name' => __('Noto Serif')],
            ['css-name' => 'Hind', 'font-name' => __('Hind')],
            ['css-name' => 'Fira+Sans', 'font-name' => __('Fira Sans')]
        ];
    }
	
	public function getLinksFont() {
        $setting = [
			'default_font' => $this->getStoreConfig('mgstheme/fonts/default_font'),
			'h1' => $this->getStoreConfig('mgstheme/fonts/h1'),
			'h2' => $this->getStoreConfig('mgstheme/fonts/h2'),
			'h3' => $this->getStoreConfig('mgstheme/fonts/h3'),
			'h4' => $this->getStoreConfig('mgstheme/fonts/h4'),
			'h5' => $this->getStoreConfig('mgstheme/fonts/h5'),
			'h6' => $this->getStoreConfig('mgstheme/fonts/h6'),
			'price' => $this->getStoreConfig('mgstheme/fonts/price'),
			'menu' => $this->getStoreConfig('mgstheme/fonts/menu'),
		];
        $fonts = [];
        $fonts[] = $setting['default_font'];

        if (!in_array($setting['h1'], $fonts)) {
            $fonts[] = $setting['h1'];
        }

        if (!in_array($setting['h2'], $fonts)) {
            $fonts[] = $setting['h2'];
        }

        if (!in_array($setting['h3'], $fonts)) {
            $fonts[] = $setting['h3'];
        }

        if (!in_array($setting['price'], $fonts)) {
            $fonts[] = $setting['price'];
        }

        if (!in_array($setting['menu'], $fonts)) {
            $fonts[] = $setting['menu'];
        }

        $fonts = array_filter($fonts);
        $links = '';

        foreach ($fonts as $_font) {
			$links .= '<link href="//fonts.googleapis.com/css?family=' . $_font . ':300,400,500,600,700,900,300italic,400italic,500italic,600italic,700italic,900italic" rel="stylesheet" type="text/css"/>';
        }

        return $links;
    }
	
	// get theme color
    public function getThemecolorSetting($storeId) {
        $setting = [
			'modal-popup .modal-footer .action-secondary:hover, .modal-popup .modal-footer .action-primary, .panel.panel-custom .panel-heading a, .panel.panel-custom .panel-heading a:hover, .panel.panel-custom .panel-heading a:focus, .nav.nav-pills.nav-bordered > li > a:hover, .nav.nav-pills.nav-bordered > li > a:focus, .nav.nav-pills.nav-bordered > li.active > a, .nav.nav-pills.nav-bordered.v2 > li.active > a, .nav.nav-pills.nav-bordered.v2 > li > a:hover, .nav.nav-pills.nav-bordered.v2 > li > a:focus, .btn.btn-custom, .btn.btn-promo-banner, .btn.btn-custom:hover, .btn.btn-promo-banner:hover, .btn.btn-custom:focus, .btn.btn-promo-banner:focus, .btn.btn-custom.btn-border, .btn.btn-promo-banner.btn-border, .btn.btn-custom.btn-border:hover, .btn.btn-promo-banner.btn-border:hover, .btn.btn-custom.btn-border:focus, .btn.btn-promo-banner.btn-border:focus, .btn.btn-custom2, .btn.btn-custom2.btn-border, .btn.btn-custom2.btn-border:hover, .btn.btn-custom2.btn-border:focus, .btn.btn-gray.btn-border:hover, .btn.btn-gray.btn-border:focus, .btn.btn-gray2.btn-border:hover, .btn.btn-gray2.btn-border:focus, .btn.btn-gray3.btn-border:hover, .btn.btn-gray3.btn-border:focus, .btn.btn-white:hover ,.btn.btn-white:focus, .btn.btn-white.btn-border:hover, .btn.btn-white.btn-border:focus, .btn.btn-dark:hover, .btn.btn-dark:focus, .btn.btn-dark.btn-border:hover, .btn.btn-dark.btn-border:focus, .btn.btn-dark2.btn-border:hover, .btn.btn-dark2.btn-border:focus, .form-control:focus, .textarea-container .form-control:focus, .content-header .dropdowns-container .header-dropdown ul li:hover > a, .content-header .dropdowns-container .header-dropdown ul li a:hover, .content-header .dropdowns-container .header-dropdown ul li a:focus, .content-header .search-form.select-search .search-select ul, .owl-carousel.owl-theme .owl-dots .owl-dot.active span, .owl-carousel.owl-theme .owl-nav [class*="owl-"]:hover, .slider_mgs_carousel.owl-theme .owl-controls .owl-nav [class*="owl-"]:hover, .slider_mgs_carousel.owl-theme .owl-controls .owl-dots .owl-dot span:hover, .slider_mgs_carousel.owl-theme .owl-controls .owl-dots .owl-dot.active span, .header.active-sticky, .footer .footer-container.footer-v2 .footer-newsletter form .btn:hover,.footer .footer-container.footer-v2 .footer-newsletter form .btn:focus, .footer .footer-container.footer-v6 .footer-middle-content .ft-widget .contact-list li:hover .icon, .footer .footer-container.footer-v7 .footer-middle-content .ft-widget .contact-list li:hover .icon, .footer .product-list-block .owl-carousel.owl-theme .owl-nav [class*="owl-"]:hover,.footer .product-list-block .owl-carousel.owl-theme .owl-nav [class*="owl-"]:focus, .pagination-container .pagination > li > a:hover,.pagination-container .pagination > li > span:hover, .pagination-container .pagination > li > a:focus,.pagination-container .pagination > li > span:focus, .pagination-container .pagination > li.active > a,.pagination-container .pagination > li.active > a:hover,.pagination-container .pagination > li.active > a:focus, .pagination-container .pagination > li.active > span, .pagination-container .pagination > li.active > span:hover,.pagination-container .pagination > li.active > span:focus, .sidebar > .block.block-blog-tags .block-content a:hover,.sidebar > .block.block-blog-tags .block-content a:focus, .sidebar > .block.block-compare .product-items .product-item .action span, .tabs_categories_porfolio li.active a, .modal-gallery.modal .modal-gallery-dialog.modal-dialog.modal--fullscren .modal-body.owl-theme .owl-controls .owl-dots .owl-dot.active span, .modal-gallery.modal .modal-gallery-dialog.modal-dialog.modal--fullscren .modal-body.owl-theme .owl-controls .owl-dots .owl-dot:hover span, .shop-by-brand .characters .characters-filter > li, .shop-by-brand .characters .view-all, .field.choice [type="checkbox"]:not(:checked):focus + label:before,.field.choice [type="checkbox"]:checked:focus + label:before, .field.choice input[type="radio"] + label:hover:after , .field.choice input[type="radio"]:checked + label:after, .items.order-links li.current,.items.order-links li:hover, .form-wishlist-items .wishlist-table tr td .product-item-inner > .product-item-actions a span, .checkout-index-index .checkout-container .opc-progress-bar li._active, .checkout-index-index .opc-wrapper .opc li.checkout-payment-method .action.primary.checkout, .checkout-index-index .shipping-address-items .shipping-address-item.selected-item .content, .multicheckout.address .table-wrapper .items.table tbody tr td.actions .action:hover,.multicheckout.address .table-wrapper .items.table tbody tr td.actions .action:focus , .scroll-to-top:hover, .title-color-white.mgs-brand-widget .owl-carousel.owl-theme .owl-nav [class*="owl-"]:hover, .checkout-cart-index .cart-summary .checkout-methods-items .item .action.checkout, .btn-add-cart:hover,.btn-add-wishlist:hover, .product-item-grid.product-v4 .product-top figure .swiper-button-next:hover,.product-item-grid.product-v4 .product-top figure .swiper-button-prev:hover, .product-item-grid.product-v5 .product-action button.btn-add-cart, .white-color .owl-carousel.owl-theme .owl-nav [class*="owl-"]:hover, .deal-grid .product-item-grid.product-v2:hover .product-countdown .deal-timer .countdown > span, .swiper-button-next:hover,.swiper-button-prev:hover, .widget-latest-posts .owl-carousel.owl-theme .owl-nav [class*="owl-"]:hover,.widget-latest-posts .owl-carousel.owl-theme .owl-nav [class*="owl-"]:focus, .sidebar .owl-carousel.owl-theme .owl-nav [class*="owl-"]:hover , .sidebar.sidebar-v2 .block .block-title h3.sidebar.sidebar-v2 .widget-latest-posts h4 .sidebar.sidebar-v2 .testimonials-container-slider .title-block h2, .sidebar .block.filter .filter-options-content .swatch-attribute a.swatch-option-link-layered:hover .swatch-option, .block-tagcloud .tagcloud a:hover, .socials-feed-slider .carousel-indicators li.active .feed-icon,.socials-feed-slider .carousel-indicators li:hover .feed-icon, .socials-feed-slider .carousel-indicators li.active .feed-icon:after,.socials-feed-slider .carousel-indicators li:hover .feed-icon:after, .socials-feed-slider .carousel-indicators li.active .feed-icon,.socials-feed-slider .carousel-indicators li:hover .feed-icon ,.block-product-grid .outside:hover, .promobanner.custom-btn-white .btn-promo-banner:hover, .promobanner.custom-btn-dark .btn-promo-banner:hover, .promobanner.custom-btn-blue .btn-promo-banner, .navigation-left-right .owl-theme.owl-carousel .owl-nav [class*="owl-"]:hover, .product-details-box, .product-view-info .product-options-wrapper .swatch-attribute .swatch-attribute-options .swatch-option:hover, .product-view-info .product-options-bottom, .product-view-info .fotorama__nav--thumbs .fotorama__nav__frame.fotorama__active .fotorama__thumb, .custom-tab-container .product-tab-category .nav.nav-icons.nav-justified > li.active a,.slider_mgs_carousel.owl-carousel .owl-nav > div:not(.disabled):hover,.scroll-to-top:focus, .content-header.header-v1 .search-form.select-search .search-select ul,.owl-carousel .owl-nav > div:not(.disabled):hover,.content-header.header-v1 .middle-header-content, .content-header.header-v1 .middle-header-content,.sidebar .owl-carousel .owl-nav [class*="owl-"]:hover,.sidebar.sidebar-v2 .block .block-title h3,.owl-carousel .owl-dots .owl-dot.active span,.owl-carousel .owl-dots .owl-dot:hover span,.product-item.product-v4 .product-item-grid .product-item-details .product-actions button, .product-item.product-v4 .product-item-grid .product-item-details .product-actions button:hover,.navigation-left-right .owl-carousel .owl-nav [class*="owl-"]:hover,.slider_mgs_carousel.owl-carousel .owl-dots .owl-dot.active span,.mgs-blog-latest-posts.blog-style5 .blog-content-wrapper .btn.btn-readmore,.footer .footer-container.footer-v5 .footer-middle-content .custombg-widget-wrapper .ft-widget .contact-list li .icon,.banner-home6.btn-light .banner-button .btn-promo-banner.btn:hover,.banner-twitters .owl-carousel .owl-dots .owl-dot.active span,.banner-twitters .owl-carousel .owl-dots .owl-dot:hover span,.promobanner.banner_home7_2 .btn.btn-promo-banner,.custom-height .big-deals .product-item.product-v3 .product-item-grid .product-item-details .product-actions .btn-add-cart,body > .sidebar-dark .block-title .title,.products-grid.product-show-description .product-item .product-item-grid .product-item-details .btn-add-cart:hover,.banner-home6 .banner-button .btn-promo-banner.btn:hover ' => [
				'border-color' => $this->getStoreConfig('color/general/theme_color', $storeId)
			],
			'.base-color, a, .nav.nav-tabs.v2 > li > a:hover, .nav.nav-tabs.v2 > li > a:focus, .nav.nav-tabs.v2 > li.active > a, .nav.nav-pills.nav-bordered > li > a:hover, .nav.nav-pills.nav-bordered > li > a:focus, .nav.nav-pills.nav-bordered > li.active > a, .nav.nav-pills.nav-bordered.v2 > li.active > a, .nav.nav-pills.nav-bordered.v2 > li > a:hover, .nav.nav-pills.nav-bordered.v2 > li > a:focus, .btn.btn-custom.btn-border, .btn.btn-promo-banner.btn-border, .btn.btn-custom2.btn-border, .form-group.control-icon .icon , .input-required, .header-info .icon-info, .content-header.header-v6 .middle-header-content .btn-open--menu:hover, .content-header.header-v6 .middle-header-content .btn-open--menu:focus , .content-header.header-v6 .middle-header-content .search-form .btn-open-search:hover, .content-header.header-v6 .middle-header-content .search-form .btn-open-search:focus, .content-header.header-v6 .middle-header-content .search-form:hover .btn-open-search, .content-header.header-v6 .middle-header-content .search-form.open .btn-open-search, .content-header.header-v7 .middle-header-content .search-form .minisearch .form-search .button:hover, .content-header.header-v7 .middle-header-content .search-form .minisearch .form-search .button:focus, .content-header.header-v5 .top-header-content .top-dropdown > a > .fa, .content-header.header-v5 .top-header-content .register-dropdown li > a .fa, .content-header.header-v5 .middle-header-content .menu > li.open > a, .content-header.header-v5 .middle-header-content .menu > li:hover > a, .content-header.header-v5 .middle-header-content .menu > li:focus > a, .content-header.header-v4 .middle-header-content .dropdowns-container .header-dropdown > li > a:hover, .content-header.header-v4 .middle-header-content .dropdowns-container .header-dropdown > a:hover, .content-header.header-v4 .middle-header-content .dropdowns-container .header-dropdown:hover > li > a, .content-header.header-v4 .middle-header-content .dropdowns-container .header-dropdown.open > li > a, .content-header.header-v4 .middle-header-content .dropdowns-container .header-dropdown:hover > a, .content-header.header-v4 .middle-header-content .dropdowns-container .header-dropdown.open > a, .content-header .dropdowns-container .header-dropdown > li:hover > a, .content-header .dropdowns-container .header-dropdown > li:focus > a, .content-header .dropdowns-container .header-dropdown > li.open > a, .content-header .dropdowns-container .header-dropdown ul li.active span, .content-header .dropdowns-container .header-dropdown.minicart-wrapper .dropdown-menu ol.minicart-items li.item.product .product-item-details .product-item-name a:hover, .content-header .dropdowns-container .header-dropdown.minicart-wrapper .dropdown-menu ol.minicart-items li.item.product .minicart-price .price, .content-header .dropdowns-container .header-dropdown.minicart-wrapper:hover .fa-shopping-cart, .content-header .search-form.select-search .search-select ul li.parent > span:hover, .content-header .search-form.select-search .search-select ul li.parent > span:focus, .content-header .search-form.select-search .search-select ul li span:hover,.content-header .search-form.select-search .search-select ul li span:focus, .content-header .search-form .btn-open-search:hover .fa, .content-header .search-form.open .btn-open-search .fa, .slider_mgs_carousel.on-load:after, .header-v3.content-header .dropdowns-container .header-dropdown.minicart-wrapper > a.showcart .fa-shopping-cart, .header-v3.content-header .dropdowns-container .header-dropdown.minicart-wrapper:hover > a .dropdown-text, .header-v3.content-header .dropdowns-container .header-dropdown.register-dropdown > li > a .fa, .header-v3.content-header .dropdowns-container .header-dropdown.register-dropdown:hover > li > a span, .header-v3.content-header .dropdowns-container .search-form .btn-open-search .fa, .change-form > span:hover, .full_page--form .change-form > span:hover, .btn-responsive-menu:focus, .ft-widget .info-box .icon, .footer a:hover,.footer a:focus, .footer .footer-container .footer-bottom-content a:hover,.footer .footer-container .footer-bottom-content a:focus, .footer .footer-container .footer-bottom-content .footer-menu.active a, .footer .footer-container.footer-v3 a:hover,.footer .footer-container.footer-v3 a:focus, .footer .footer-container.footer-v3 .footer-top-content .tweets-list li a , .footer .footer-container.footer-v4 .footer-middle-content a:hover,.footer .footer-container.footer-v4 .footer-middle-content a:focus, .footer .footer-container.footer-v5 .footer-middle-content a:hover,.footer .footer-container.footer-v5 .footer-middle-content a:focus, .footer .footer-container.footer-v5 .footer-middle-content .ft-widget.widget-twitter .tweets-list li .tweet-top .tweet-user h5 a:hover, .footer .footer-container.footer-v5 .footer-middle-content .ft-widget.widget-twitter .tweets-list li .tweet-top .tweet-user h5 a:focus, .footer .footer-container.footer-v5 .footer-middle-content .ft-widget.widget-twitter .tweets-list li .tweet-top .tweet-user > p > a:hover,.footer .footer-container.footer-v5 .footer-middle-content .ft-widget.widget-twitter .tweets-list li .tweet-top .tweet-user > p > a:focus, .footer .footer-container.footer-v5 .footer-middle-content .product-list-block .product-item-grid .product-meta .product-title a:hover, .footer .footer-container.footer-v5 .footer-middle-content .product-list-block .product-item-grid .product-meta .product-title a:focus, .footer .footer-container.footer-v7 .footer-middle-content a:hover,.footer .footer-container.footer-v7 .footer-middle-content a:focus, .footer .tweets-list li a, .footer .product-list-block .product-item-grid .product-meta .product-title a:hover, .footer .product-list-block .product-item-grid .product-meta .product-title a:focus, .footer .product-list-block .product-item-grid .product-meta .product-price-container .price-box .price, .blog-post-single .post-info .post-single--footer .entry-meta-container .entry-meta a:hover, .blog-post-single .post-info .post-single--footer .entry-meta-container .entry-meta a:focus, .pagination-container .pagination > li.active > a,.pagination-container .pagination > li.active > a:hover,.pagination-container .pagination > li.active > a:focus, .pagination-container .pagination > li.active > span, .pagination-container .pagination > li.active > span:hover, .pagination-container .pagination > li.active > span:focus, .sidebar > .block.block-blog-categories .post-category-list li a:hover,.sidebar > .block.block-blog-categories .post-category-list li a:focus, .sidebar > .block.block-compare .product-items .product-item .product-item-name a:hover, .sidebar > .block.block-compare .product-items .product-item .product-item-name a:focus, .sidebar > .block.account-nav .items .item a:hover,.sidebar > .block.account-nav .items .item a:focus, .sidebar > .block.account-nav .items .item strong, .sidebar > .block .sidebar .account-nav .items .item .sidebar .account-nav .items .item a:hover,.sidebar > .block .sidebar .account-nav .items .item a:focus, .sidebar > .block .sidebar .account-nav .items .item strong, .blog-list.classic .blog-post .entry-title a:hover, .blog-list.classic .blog-post .entry-title a:focus, .blog-list.masonry .entry-content-wrapper:hover, .blog-list.masonry .entry-content-wrapper .post-content-wrapper .entry-title a:hover, .blog-list.masonry .entry-content-wrapper .post-content-wrapper .entry-title a:focus, .tabs_categories_porfolio li a:hover, .tabs_categories_porfolio li a:focus, .tabs_categories_porfolio li.active a, .portfolio-grid .item .portfolio-bottom-content h5 a:hover,.portfolio-grid .item .portfolio-bottom-content h5 a:focus , .portfolio-grid .item .portfolio-bottom-content .category-link a:hover, .portfolio-grid .item .portfolio-bottom-content .category-link a:focus , .contact-info a:hover,.contact-info a:focus, .shop-by-brand .brand-list .brand-title a:hover, .shop-by-brand .brand-list .brand-title a:focus, .table-wrapper.comparison .table-comparison tbody > tr > td .product-item-name a:hover,.table-wrapper.comparison .table-comparison tbody > tr > td .product-item-name a:focus, .table-wrapper.comparison .table-comparison tbody > tr > td .product-item-actions .action.delete:hover,.table-wrapper.comparison .table-comparison tbody > tr > td .product-item-actions .action.delete:focus, .field.choice [type="checkbox"]:not(:checked) + label:after,.field.choice [type="checkbox"]:checked + label:after, .block-title--myac h3 a, .block-order-details-comments .order-comments .comment .comment-date, .items.order-links li.current,.items.order-links li:hover, .account .order-details-items .table-wrapper tfoot tr td.grand_total .price, .review-customer-view .customer-review.view .product-info .product-name a:hover,.review-customer-view .customer-review.view .product-info .product-name a:focus, .review-customer-view .customer-review.view .review-details .review-date, .form-wishlist-items .wishlist-table tr td .product-item-name a:hover,.form-wishlist-items .wishlist-table tr td .product-item-name a:focus, .checkout-index-index .checkout-container .opc-progress-bar li._active, .checkout-index-index .opc-sidebar.opc-summary-wrapper .modal-content .opc-block-summary .table-totals tr.grand.totals .price, .checkout-index-index .opc-sidebar.opc-summary-wrapper .modal-content .opc-block-shipping-information .shipping-information .shipping-information-title .action:hover, .checkout-index-index .opc-sidebar.opc-summary-wrapper .modal-content .items-in-cart .minicart-items-wrapper .minicart-items .product-item .product .product-item-details .subtotal .price, .multicheckout.address .table-wrapper .items.table tbody tr td.product a:hover,.multicheckout.address .table-wrapper .items.table tbody tr td.product a:focus, .multicheckout.shipping > .block-shipping .block-content .box-items table tbody tr td.item a:hover,.multicheckout.shipping > .block-shipping .block-content .box-items table tbody tr td.item a:focus, .multicheckout.order-review .block.block-shipping .block-content .order-review-wrapper table tbody tr td.item a:hover,.multicheckout.order-review .block.block-shipping .block-content .order-review-wrapper table tbody tr td.item a:focus, .multicheckout.order-review .block.block-shipping .block-content .order-review-wrapper table tfoot tr.grand.totals td .price, .multicheckout.order-review .checkout-review .grand.totals .amount .price, .info-boxes-container .info-box .icon, .checkout-cart-index #shopping-cart-table tbody tr:first-child td.col.item .product-item-details .product-item-name a:hover,.checkout-cart-index #shopping-cart-table tbody tr:first-child td.col.item .product-item-details .product-item-name a:focus, .checkout-cart-index #shopping-cart-table .subtotal .cart-price .price, .checkout-cart-index #shopping-cart-table .gift-options-cart-item .action-gift._active,.checkout-cart-index #shopping-cart-table .gift-options-cart-item .action-gift:hover, .checkout-cart-index .shopping-cart-bottom .cart-totals .table.totals tbody tr tr.grand.totals .price, .price-box .price-wrapper , .product-reviews-summary:not(.short) .reviews-actions a:hover, .product-item-grid .product-title a:hover, .product-item-grid.product-v4 .product-title a:hover , .product-item-grid.product-v5 .product-title a:hover , .product-item-grid.product-v5 .product-action button.btn-add-cart, .mgs-blog-latest-posts .blog-content-wrapper .blog-title a:hover, .mgs-blog-latest-posts.widget-blog-v2 .entry-content-wrapper .entry-title a:hover , .widget-latest-posts .post-content .post-meta h5 a:hover,.widget-latest-posts .post-content .post-meta h5 a:focus , .sidebar .block-comment .latest-comment .lcomment-meta h5 a:hover, .sidebar .block.filter .filter-options-content .items .item a:hover, .sidebar .block.filter .filter-options-content .items .item a .price,.nav.nav-pills.vertical-menu > li > a:hover, .ins-feed .ins-meta .ins-hashtag:hover, .ins-feed .ins-meta .ins-info a .fa, .blue-text, .promobanner.custom-btn-blue .btn-promo-banner, .nav-tab-v2 .nav.nav-icons.nav-justified > li.active > a,.nav-tab-v2 .nav.nav-icons.nav-justified > li:hover > a, .nav-tab-v3.product-tab-attribute .tab-attribute .nav.nav-pills.nav-bordered > li.active > a,.nav-tab-v3.product-tab-attribute .tab-attribute .nav.nav-pills.nav-bordered > li:hover > a , .toolbar-products .modes .modes-mode.active,.toolbar-products .modes .modes-mode:hover, .product-view-info .product-brand a:hover , .product-view-info .product-info-price .available span.text-custom, .bundle-options-wrapper .product-options-wrapper .fieldset-bundle-options > .field .options-list .price-notice .price , .block-bundle-summary .bundle-info .product-details p.stock .custom-text, .block-related .block-actions .action.select,.content-header .dropdowns-container .header-dropdown.currency-language > li > ul > li .fa,.menu li.mega-menu-fullwidth > ul.dropdown-menu ul li.open > a, .product-item .product-item-details .product-name a:hover,.header-v2.content-header .header-megamenu .menu-container .menu > li.open > a,.top-header-content .top-dropdown > ul li:hover,.footer .footer-container.footer-v3 .footer-top-content .tweets-list li .tweet-top + * a,.header-v4.content-header .header-megamenu .menu-container .menu > li.open > a,.product-item.product-v4 .product-item-grid .product-item-details .product-name a:hover,.header-v5.content-header .search-form .minisearch .form-search .button,.mgs-blog-latest-posts.blog-style5 .blog-content-wrapper .btn.btn-readmore,.header-v7.content-header .header-megamenu .menu-container .menu > li.open > a,.footer .footer-container.footer-v8 .footer-top-content .block-subscribe .btn:hover,.footer .footer-container.footer-v8 .footer-middle-content a:hover,.top-header-content .top-dropdown > ul li.active,.top-header-content .top-dropdown > ul li:hover a,.promobanner.banner_home7_2 .btn.btn-promo-banner,.custom-height .product-item.product-v3 .product-item-grid .product-item-details .price-box .price,.custom-height .big-deals .product-item.product-v3 .product-item-grid .product-item-details .product-actions .btn-add-cart,body > .sidebar-dark .block-vertical-menu .nav.nav-pills.vertical-menu > li > a:hover   ' => [
				'color' => $this->getStoreConfig('color/general/theme_color', $storeId)
			],
			'modal-popup .modal-footer .action-secondary:hover, .modal-popup .modal-footer .action-primary, .overlay-container .overlay.custom, .overlay-container .overlay.custom2, .highlight .custom, .highlight.custom2, .dropcap.custom:first-letter, .dropcap.custom2:first-letter, .btn.btn-custom, .btn.btn-promo-banner, .btn.btn-custom:hover, .btn.btn-promo-banner:hover, .btn.btn-custom:focus, .btn.btn-promo-banner:focus, .btn.btn-custom.btn-border:hover, .btn.btn-promo-banner.btn-border:hover, .btn.btn-custom.btn-border:focus, .btn.btn-promo-banner.btn-border:focus, .btn.btn-custom2, .btn.btn-custom2.btn-border:hover, .btn.btn-custom2.btn-border:focus, .btn.btn-gray.btn-border:hover, .btn.btn-gray.btn-border:focus, .btn.btn-gray2.btn-border:hover, .btn.btn-gray2.btn-border:focus, .btn.btn-gray3.btn-border:hover, .btn.btn-gray3.btn-border:focus, .btn.btn-white:hover, .btn.btn-white:focus, .btn.btn-white.btn-border:hover, .btn.btn-white.btn-border:focus, .btn.btn-dark:hover, .btn.btn-dark:focus, .btn.btn-dark.btn-border:hover, .btn.btn-dark.btn-border:focus, .content-header.header-v7 .header-megamenu, .content-header.header-v5 .top-header-content .register-dropdown:hover li > a, .content-header.header-v5 .top-header-content .register-dropdown.open li > a, .content-header.header-v4 .top-header-content, .content-header ul.social li a:hover, .content-header .dropdowns-container .header-dropdown ul li:hover > a, .content-header .dropdowns-container .header-dropdown ul li a:hover, .content-header .dropdowns-container .header-dropdown ul li a:focus, .content-header .dropdowns-container .header-dropdown.minicart-wrapper > a.showcart span.counter-number, .content-header .search-form .minisearch .form-search .button:hover, .content-header .search-form .minisearch .form-search .button:focus, .content-header .search-form.select-search .search-select > a, .owl-carousel.owl-theme .owl-dots .owl-dot.active span, .owl-carousel.owl-theme .owl-nav [class*="owl-"]:hover ,  .slider_mgs_carousel.owl-theme .owl-controls .owl-nav [class*="owl-"]:hover, .header-v2.content-header .header-megamenu, .footer .footer-container .footer-middle-content .ft-widget .contact-list li:hover .icon, .footer .footer-container.footer-v2 .footer-newsletter form .btn:hover,.footer .footer-container.footer-v2 .footer-newsletter form .btn:focus, .footer .footer-container.footer-v4 .footer-middle-content .ft-widget .contact-list li:hover .icon, .footer .footer-container.footer-v5 .footer-middle-content .custombg-widget-wrapper:before, .footer .footer-container.footer-v6 .footer-middle-content .ft-widget .contact-list li:hover .icon, .footer .footer-container.footer-v7 .footer-middle-content .ft-widget .contact-list li:hover .icon, .footer .product-list-block .owl-carousel.owl-theme .owl-nav [class*="owl-"]:hover, .footer .product-list-block .owl-carousel.owl-theme .owl-nav [class*="owl-"]:focus, .pagination-container .pagination > li > a:hover,.pagination-container .pagination > li > span:hover, .pagination-container .pagination > li > a:focus, .pagination-container .pagination > li > span:focus, .sidebar > .block.block-blog-tags .block-content a:hover, .sidebar > .block.block-blog-tags .block-content a:focus, .sidebar > .block.block-compare .product-items .product-item .action:hover span, .portfolio-grid .item .portfolio-top-content .link-portfolio > a, .portfolio-index-view .detail-gallery .item-gallery-img .open-gallery, .contact-layout2 .form-map-contact .show-form, .shop-by-brand .characters .characters-filter > li:hover, .shop-by-brand .characters .view-all:hover, .field.choice input[type="radio"] + label:before, .form-wishlist-items .wishlist-table tr td .product-item-inner > .product-item-actions a:hover span, .form-wishlist-items .wishlist-table tr td .product-item-inner > .product-item-actions a:focus span, .checkout-index-index .checkout-container .opc-progress-bar li._active:after, .checkout-index-index .opc-wrapper .opc li.checkout-payment-method .action.primary.checkout, .multicheckout.address .table-wrapper .items.table tbody tr td.actions .action:hover, .multicheckout.address .table-wrapper .items.table tbody tr td.actions .action:focus, .scroll-to-top:hover, .progress .progress-bar .progress-val, .progress.progress-sm .progress-bar, .title-color-white.mgs-brand-widget .owl-carousel.owl-theme .owl-nav [class*="owl-"]:hover, .checkout-cart-index .cart-summary .checkout-methods-items .item .action.checkout , .product-label, .btn-add-cart:hover, .btn-add-wishlist:hover, .product-item-grid.product-v4 .product-top figure .swiper-button-next:hover, .product-item-grid.product-v4 .product-top figure .swiper-button-prev:hover,  .product-item-grid.product-v5 .product-action button.btn-add-cart:hover, .white-color .owl-carousel.owl-theme .owl-nav [class*="owl-"]:hover, .deal-grid .product-item-grid.product-v2:hover .product-countdown .deal-timer .countdown > span, .swiper-button-next:hover, .swiper-button-prev:hover, .widget-latest-posts .owl-carousel.owl-theme .owl-nav [class*="owl-"]:hover, .widget-latest-posts .owl-carousel.owl-theme .owl-nav [class*="owl-"]:focus, .block-tagcloud .tagcloud a:hover,  .socials-feed-slider .carousel-indicators li.active .feed-icon, .socials-feed-slider .carousel-indicators li:hover .feed-icon, .socials-feed-slider .carousel-indicators li.active .feed-icon,.socials-feed-slider .carousel-indicators li:hover .feed-icon, .block-product-grid .outside:hover , .promobanner.custom-btn-white .btn-promo-banner:hover, .promobanner.custom-btn-dark .btn-promo-banner:hover, .promobanner.custom-btn-blue .btn-promo-banner:hover, .navigation-left-right .owl-theme.owl-carousel .owl-nav [class*="owl-"]:hover, .product-tab-detailed .items .item.title.active a, .product-tab-detailed .items .item.title a:hover, .product-label.new-label,.menu > li.open > a,.slider_mgs_carousel.owl-carousel .owl-nav > div:not(.disabled):hover,.scroll-to-top:focus, .menu li li.open > a,.content-header.header-v1 .search-form.select-search .search-select > a,.owl-carousel .owl-nav > div:not(.disabled):hover, .header.active-sticky .content-header.header-v2 .header-megamenu .menu-container .menu > li.open > a,.top-header-content .top-dropdown:hover > a,.owl-carousel .owl-dots .owl-dot.active span,.owl-carousel .owl-dots .owl-dot:hover span,.product-item.product-v4 .product-item-grid .product-item-details .product-actions button,.product-item.product-v4 .product-item-grid .product-item-details .product-actions button:hover,.navigation-left-right .owl-carousel .owl-nav [class*="owl-"]:hover,.header-v5.content-header .middle-header-content,.mgs-blog-latest-posts.blog-style5 .blog-content-wrapper .btn.btn-readmore:hover,.footer .footer-container.footer-v5 .footer-middle-content .custombg-widget-wrapper .ft-widget .contact-list li .icon,.footer .footer-container.footer-v5 .footer-middle-content .custombg-widget-wrapper a:hover,.header.active-sticky .content-header.header-v7 .header-megamenu .menu-container .menu > li.open > a,.banner-home6.btn-light .banner-button .btn-promo-banner.btn:hover,.menu-v3 .nav-icon.nav-tabs > li.title h3:after,.promobanner.banner_home7_2 .btn.btn-promo-banner:hover,.footer .footer-container.footer-v9 .footer-top-content,.header-v6.content-header .header-bottom,.progress .progress-bar,.breadcrumbs .page-header.page-header-v1, .breadcrumbs .page-header.page-header-v2,.banner-home6 .banner-button .btn-promo-banner.btn:hover  ' => [
				'background-color' => $this->getStoreConfig('color/general/theme_color', $storeId)
			]
		];
        $setting = array_filter($setting);
        return $setting;
    }
	
	// get header custom color
    public function getHeaderColorSetting($storeId) {
        $setting = [
            /* Header Top Section */
            '.top-header-content' => [
                'color' => $this->getStoreConfig('color/header/top_text_color', $storeId),
				'background-color' => $this->getStoreConfig('color/header/top_background_color', $storeId),
				'border-color' => $this->getStoreConfig('color/header/top_border_color', $storeId)
            ],
			'.top-header-content .top-dropdown > a,.top-header-content .register-dropdown li > a' => [
                'background-color' => $this->getStoreConfig('color/header/top_open_dropdown_bg', $storeId),
                'color' => $this->getStoreConfig('color/header/top_open_dropdown_color', $storeId),
            ],
			'.top-header-content .top-dropdown > ul li' => [
				'background-color' => $this->getStoreConfig('color/header/top_open_dropdown_bg', $storeId)
			],
			'.top-header-content .top-dropdown:hover > a,.top-header-content .top-dropdown.open > a,.top-header-content .register-dropdown:hover li > a,.top-header-content .register-dropdown.open li > a' => [
                'background-color' => $this->getStoreConfig('color/header/top_open_dropdown_bg_hover', $storeId),
                'color' => $this->getStoreConfig('color/header/top_open_dropdown_color_hover', $storeId),
            ],
			'.top-header-content .top-dropdown > a .fa,.top-header-content .register-dropdown li > a .fa' => [
                'color' => $this->getStoreConfig('color/header/top_open_icon_color', $storeId)
            ],
			'.top-header-content .top-dropdown:hover > a .fa,.top-header-content .top-dropdown.open > a .fa,.top-header-content .register-dropdown:hover li > a .fa,.top-header-content .register-dropdown.open li > a .fa' => [
                'color' => $this->getStoreConfig('color/header/top_open_icon_color_hover', $storeId)
            ],
			/* Header Social Block */
			'.content-header ul.social li a' => [
                'color' => $this->getStoreConfig('color/header/social_color', $storeId),
                'background-color' => $this->getStoreConfig('color/header/social_bg_color', $storeId),
                'border-color' => $this->getStoreConfig('color/header/social_border_color', $storeId)
            ],
			'.content-header ul.social li a:hover, .content-header ul.social li a:focus' => [
                'color' => $this->getStoreConfig('color/header/social_color_hover', $storeId),
                'background-color' => $this->getStoreConfig('color/header/social_bg_color_hover', $storeId),
                'border-color' => $this->getStoreConfig('color/header/social_border_color_hover', $storeId)
            ],
			/* Header Dropdown (My account, Currency, Languague) */
			'.content-header .dropdowns-container .header-dropdown ul,.top-header-content .top-dropdown > ul' => [
                'background-color' => $this->getStoreConfig('color/header/dropdown_background', $storeId),
                'border-color' => $this->getStoreConfig('color/header/dropdown_border_color', $storeId)
            ],
			'.content-header .dropdowns-container .header-dropdown ul li a' => [
                'background-color' => $this->getStoreConfig('color/header/dropdown_link_color_bg', $storeId),
                'border-color' => $this->getStoreConfig('color/header/dropdown_link_color_bd', $storeId),
                'color' => $this->getStoreConfig('color/header/dropdown_link_color', $storeId)
            ],
			'.top-header-content .top-dropdown > ul li' => [
                'background-color' => $this->getStoreConfig('color/header/dropdown_link_color_bg', $storeId),
                'border-color' => $this->getStoreConfig('color/header/dropdown_link_color_bd', $storeId)
            ],
			'.top-header-content .top-dropdown > ul li a' => [
                'color' => $this->getStoreConfig('color/header/dropdown_link_color', $storeId)
            ],
			'.top-header-content .top-dropdown > ul li:hover, .top-header-content .top-dropdown > ul li:focus, .top-header-content .top-dropdown > ul li.active' => [
                'background-color' => $this->getStoreConfig('color/header/dropdown_link_color_bg_hv', $storeId),
                'border-color' => $this->getStoreConfig('color/header/dropdown_link_color_bd_hv', $storeId),
				'color' => $this->getStoreConfig('color/header/dropdown_link_color_hv', $storeId)
            ],
			'.top-header-content .top-dropdown > ul li:hover a, .top-header-content .top-dropdown > ul li:focus a, .top-header-content .top-dropdown > ul li.active a' => [
                'color' => $this->getStoreConfig('color/header/dropdown_link_color_hv', $storeId)
            ],
			'.content-header .dropdowns-container .header-dropdown ul li:hover > a, .content-header .dropdowns-container .header-dropdown ul li a:hover, .content-header .dropdowns-container .header-dropdown ul li a:focus,.content-header .dropdowns-container .header-dropdown ul li.active span' => [
                'background-color' => $this->getStoreConfig('color/header/dropdown_link_color_bg_hv', $storeId),
                'border-color' => $this->getStoreConfig('color/header/dropdown_link_color_bd_hv', $storeId),
                'color' => $this->getStoreConfig('color/header/dropdown_link_color_hv', $storeId)
            ],
			/* Header Middle Section */
			'.middle-header-content' => [
                'background-color' => $this->getStoreConfig('color/header/middle_background_color', $storeId),
                'border-color' => $this->getStoreConfig('color/header/middle_border_color', $storeId)
            ],
			'.content-header .dropdowns-container .header-dropdown > li > a span' => [
                'color' => $this->getStoreConfig('color/header/middle_open_dropdown_color', $storeId)
            ],
			'.content-header .dropdowns-container .header-dropdown > li > a .fa,.btn-open--menu,.btn-open--menucustom' => [
                'color' => $this->getStoreConfig('color/header/middle_open_icon_color', $storeId)
            ],
			'.content-header .dropdowns-container .header-dropdown > li:hover > a span, .content-header .dropdowns-container .header-dropdown > li:focus > a span, .content-header .dropdowns-container .header-dropdown > li.open > a span' => [
                'color' => $this->getStoreConfig('color/header/middle_open_dropdown_color_hover', $storeId)
            ],
			'.content-header .dropdowns-container .header-dropdown > li:hover > a .fa, .content-header .dropdowns-container .header-dropdown > li:focus > a .fa, .content-header .dropdowns-container .header-dropdown > li.open > a .fa,.btn-open--menu:hover,.btn-open--menu:focus,.btn-open--menucustom:hover,.btn-open--menucustom:focus' => [
                'color' => $this->getStoreConfig('color/header/middle_open_icon_color_hover', $storeId)
            ],
			/* Top Search Section */
			'.content-header .search-form' => [
                'background-color' => $this->getStoreConfig('color/header/search_background', $storeId)
            ],
			'.content-header .search-form .minisearch .form-search' => [
                'border-color' => $this->getStoreConfig('color/header/search_border', $storeId)
            ],
			'.content-header .search-form .minisearch .form-search .form-control' => [
                'background-color' => $this->getStoreConfig('color/header/search_input_bg', $storeId),
                'color' => $this->getStoreConfig('color/header/search_input', $storeId)
            ],
			'.content-header .search-form .minisearch .form-search .button' => [
                'background-color' => $this->getStoreConfig('color/header/search_button_bg', $storeId),
                'color' => $this->getStoreConfig('color/header/search_button', $storeId)
            ],
			'.content-header .search-form .minisearch .form-search .button:hover,.content-header .search-form .minisearch .form-search .button:focus' => [
                'background-color' => $this->getStoreConfig('color/header/search_button_bg_hv', $storeId),
                'color' => $this->getStoreConfig('color/header/search_button_hv', $storeId)
            ],
			'.content-header .search-form .btn-open-search .fa' => [
                'color' => $this->getStoreConfig('color/header/search_button_show_ic', $storeId)
            ],
			'.content-header .search-form .btn-open-search:hover .fa,.content-header .search-form.open .btn-open-search .fa' => [
                'color' => $this->getStoreConfig('color/header/search_button_show_ic_hv', $storeId)
            ],
			'.content-header .search-form .btn-open-search .text' => [
                'color' => $this->getStoreConfig('color/header/search_button_show', $storeId)
            ],
			'.content-header .search-form .btn-open-search:hover .text,.content-header .search-form.open .btn-open-search .text' => [
                'color' => $this->getStoreConfig('color/header/search_button_show_hv', $storeId)
            ],
			'.content-header .search-form.select-search .search-select > a' => [
                'color' => $this->getStoreConfig('color/header/search_select', $storeId),
				'border-color' => $this->getStoreConfig('color/header/search_select_bg', $storeId),
				'background-color' => $this->getStoreConfig('color/header/search_select_bd', $storeId)
            ],
			'.content-header .search-form.select-search .search-select ul' => [
				'border-color' => $this->getStoreConfig('color/header/search_select_dropdown_bd', $storeId),
				'background-color' => $this->getStoreConfig('color/header/search_select_dropdown', $storeId)
            ],
			'.content-header .search-form.select-search .search-select ul li span' => [
                'color' => $this->getStoreConfig('color/header/search_select_dropdown_link', $storeId)
            ],
			'.content-header .search-form.select-search .search-select ul li span:hover, .content-header .search-form.select-search .search-select ul li span:focus' => [
                'color' => $this->getStoreConfig('color/header/search_select_dropdown_link_hv', $storeId)
            ],
			/* Login Form */
			'.register-header' => [
                'background-color' => $this->getStoreConfig('color/header/login_background', $storeId),
                'border-color' => $this->getStoreConfig('color/header/login_border', $storeId)
            ],
			'.register-dropdown .register-header .dropdown-title' => [
                'color' => $this->getStoreConfig('color/header/login_title', $storeId)
            ],
			'.change-form > span' => [
                'color' => $this->getStoreConfig('color/header/login_link', $storeId)
            ],
			'.change-form > span:hover' => [
                'color' => $this->getStoreConfig('color/header/login_link_hover', $storeId)
            ],
			'.register-header .form-group.control-icon .form-control' => [
                'color' => $this->getStoreConfig('color/header/login_input_color', $storeId),
                'background-color' => $this->getStoreConfig('color/header/login_input_background', $storeId),
                'border-color' => $this->getStoreConfig('color/header/login_input_bd', $storeId)
            ],
			'.register-header .form-group.control-icon .icon' => [
                'color' => $this->getStoreConfig('color/header/login_input_icon', $storeId)
            ],
			/* Top Cart Section */
			'.minicart-wrapper .action.showcart' => [
                'color' => $this->getStoreConfig('color/header/cart_open_link', $storeId)
            ],
			'.minicart-wrapper:hover > a .dropdown-text,.minicart-wrapper.active > a .dropdown-text' => [
                'color' => $this->getStoreConfig('color/header/cart_open_link_hv', $storeId)
            ],
			'.minicart-wrapper .action.showcart .fa' => [
                'color' => $this->getStoreConfig('color/header/cart_icon', $storeId)
            ],
			'.minicart-wrapper .action.showcart .fa' => [
                'color' => $this->getStoreConfig('color/header/cart_icon', $storeId)
            ],
			'.minicart-wrapper .count .counter-number' => [
                'background-color' => $this->getStoreConfig('color/header/cart_number_background', $storeId),
                'color' => $this->getStoreConfig('color/header/cart_number', $storeId)
            ],
			'.minicart-wrapper > .dropdown-menu' => [
                'background-color' => $this->getStoreConfig('color/header/cart_dropdown_background', $storeId),
                'border-color' => $this->getStoreConfig('color/header/cart_dropdown_border', $storeId),
                'color' => $this->getStoreConfig('color/header/cart_dropdown_text', $storeId),
            ],
			'.minicart-wrapper .ui-widget-content .block-content, .minicart-wrapper .ui-widget-content .block-content .subtitle' => [
                'color' => $this->getStoreConfig('color/header/cart_dropdown_text', $storeId)
            ],
			'.minicart-wrapper .ui-widget-content .block-content a' => [
                'color' => $this->getStoreConfig('color/header/cart_dropdown_link', $storeId)
            ],
			'.minicart-wrapper .ui-widget-content .block-content a:hover' => [
                'color' => $this->getStoreConfig('color/header/cart_dropdown_link_hover', $storeId)
            ],
			/* Menu Section */
			'.header-megamenu' => [
                'background-color' => $this->getStoreConfig('color/header/menu_section_background', $storeId)
            ],
			'.menu > li > a' => [
                'color' => $this->getStoreConfig('color/header/menu_pr_color', $storeId),
                'background-color' => $this->getStoreConfig('color/header/menu_pr_bg', $storeId)
            ],
			'.menu > li.open > a' => [
                'color' => $this->getStoreConfig('color/header/menu_pr_color_hv', $storeId),
                'background-color' => $this->getStoreConfig('color/header/menu_pr_bg_hv', $storeId)
            ],
			'.menu li > .dropdown-menu' => [
                'background-color' => $this->getStoreConfig('color/header/menu_drd_background', $storeId),
                'border-color' => $this->getStoreConfig('color/header/menu_drd_border', $storeId)
            ],
			'.menu li li > a,.menu li.mega-menu-fullwidth > ul.dropdown-menu .mega-menu-sub-title' => [
                'color' => $this->getStoreConfig('color/header/menu_drd_link_color', $storeId)
            ],
			'.menu li li > a:hover,.menu li.mega-menu-fullwidth > ul.dropdown-menu a:hover > .mega-menu-sub-title' => [
                'color' => $this->getStoreConfig('color/header/menu_drd_link_color_hv', $storeId)
            ],
			'.menu > li:not(.mega-menu-fullwidth) li > a' => [
                'background-color' => $this->getStoreConfig('color/header/menu_drd_link_bg', $storeId)
            ],
			'.menu > li:not(.mega-menu-fullwidth) li > a:hover' => [
                'background-color' => $this->getStoreConfig('color/header/menu_drd_link_bg_hv', $storeId)
            ],
        ];
        $setting = array_filter($setting);
        return $setting;
    }
	
	// get main content custom color
    public function getMainColorSetting($storeId) {
        $setting = [
            /* Text & Link color */
            '.page-main' => [
                'color' => $this->getStoreConfig('color/main/text_color', $storeId)
            ],
			'.page-main a' => [
                'color' => $this->getStoreConfig('color/main/link_color', $storeId)
            ],
			'.page-main a:hover,.page-main a:focus' => [
                'color' => $this->getStoreConfig('color/main/link_color_hover', $storeId)
            ],
			'.page-main .price, .page-main .price-box .price' => [
                'color' => $this->getStoreConfig('color/main/price_color', $storeId)
            ],
			'.page-main .old-price .price, .page-main .price-box .old-price .price' => [
                'color' => $this->getStoreConfig('color/main/old_price_color', $storeId)
            ],
			'.page-main .old-price .price-wrapper, .page-main .price-box .old-price .price-wrapper' => [
				'-moz-text-decoration-color' => $this->getStoreConfig('color/main/old_price_color', $storeId),
				'text-decoration-color' => $this->getStoreConfig('color/main/old_price_color', $storeId)
            ],
			/* Default button color */
            '.btn.btn-custom, .btn-add-cart' => [
                'color' => $this->getStoreConfig('color/main/button_text', $storeId),
                'background-color' => $this->getStoreConfig('color/main/button_background', $storeId),
                'border-color' => $this->getStoreConfig('color/main/button_border', $storeId)
            ],
			'.product-item.product-v1 .btn-add-cart .fa' => [
				'color' => $this->getStoreConfig('color/main/button_text', $storeId)
			],
			'.btn.btn-custom:hover, .btn.btn-custom:focus, .btn-add-cart:hover, .btn-add-cart:focus' => [
                'color' => $this->getStoreConfig('color/main/button_text_hover', $storeId),
                'background-color' => $this->getStoreConfig('color/main/button_background_hover', $storeId),
                'border-color' => $this->getStoreConfig('color/main/button_border_hover', $storeId)
            ],
			'.product-item.product-v1 .btn-add-cart:hover .fa' => [
				'color' => $this->getStoreConfig('color/main/button_text_hover', $storeId)
			],
			/* Primary button color */
            '.btn.btn-custom2' => [
                'color' => $this->getStoreConfig('color/main/primary_button_text'),
                'background-color' => $this->getStoreConfig('color/main/primary_button_background', $storeId),
                'border-color' => $this->getStoreConfig('color/main/primary_button_border', $storeId)
            ],
			'.btn.btn-custom2:hover, .btn.btn-custom2:focus' => [
                'color' => $this->getStoreConfig('color/main/primary_button_text_hover', $storeId),
                'background-color' => $this->getStoreConfig('color/main/primary_button_background_hover', $storeId),
                'border-color' => $this->getStoreConfig('color/main/primary_button_border_hover', $storeId)
            ],
			/* Secondary button color */
            '.btn.btn-custom3' => [
                'color' => $this->getStoreConfig('color/main/secondary_button_text', $storeId),
                'background-color' => $this->getStoreConfig('color/main/secondary_button_background', $storeId),
                'border-color' => $this->getStoreConfig('color/main/secondary_button_border', $storeId)
            ],
			'.btn.btn-custom3:hover, .btn.btn-custom3:focus' => [
                'color' => $this->getStoreConfig('color/main/secondary_button_text_hover', $storeId),
                'background-color' => $this->getStoreConfig('color/main/secondary_button_background_hover', $storeId),
                'border-color' => $this->getStoreConfig('color/main/secondary_button_border_hover', $storeId)
            ],
			/* Breadcrumb */
            '.breadcrumbs .page-header' => [
                'background-color' => $this->getStoreConfig('color/main/breadcrumb_background_color', $storeId),
            ],
            '.breadcrumbs .page-header h1,.breadcrumbs .page-header .breadcrumb li + li::before,.breadcrumbs .page-header .breadcrumb li.active' => [
                'color' => $this->getStoreConfig('color/main/breadcrumb_text_color', $storeId),
            ],
            '.breadcrumbs .page-header .breadcrumb a' => [
                'color' => $this->getStoreConfig('color/main/breadcrumb_link_color', $storeId),
            ],
            '.breadcrumbs .page-header .breadcrumb a:hover, .breadcrumbs .page-header .breadcrumb a:focus' => [
                'color' => $this->getStoreConfig('color/main/breadcrumb_link_hover_color', $storeId),
            ],
			/*  */
        ];
        $setting = array_filter($setting);
        return $setting;
    }
	
	// get main content custom color
    public function getFooterColorSetting($storeId) {
        $setting = [
            /* Top Footer Section */
            '.footer .footer-container .footer-top-content' => [
                'background-color' => $this->getStoreConfig('color/footer/top_background_color', $storeId),
                'color' => $this->getStoreConfig('color/footer/top_text_color', $storeId),
                'border-color' => $this->getStoreConfig('color/footer/top_border_color', $storeId)
            ],
			'.footer .footer-container .footer-top-content' => [
                'color' => $this->getStoreConfig('color/footer/top_text_color', $storeId)
            ],
			'.footer .footer-container .footer-top-content h1,.footer .footer-container .footer-top-content h2,.footer .footer-container .footer-top-content h3,.footer .footer-container .footer-top-content h4,.footer .footer-container .footer-top-content h5,.footer .footer-container .footer-top-content h6' => [
                'color' => $this->getStoreConfig('color/footer/top_heading_color', $storeId)
            ],
			'.footer .footer-container .footer-top-content a' => [
                'color' => $this->getStoreConfig('color/footer/top_link_color', $storeId)
            ],
			'.footer .footer-container .footer-top-content a:hover,.footer .footer-container .footer-top-content a:focus' => [
                'color' => $this->getStoreConfig('color/footer/top_link_color_hover', $storeId)
            ],
			/* Middle Footer Section */
            '.footer .footer-container .footer-middle-content' => [
                'background-color' => $this->getStoreConfig('color/footer/middle_background_color', $storeId),
                'color' => $this->getStoreConfig('color/footer/middle_text_color', $storeId),
                'border-color' => $this->getStoreConfig('color/footer/middle_border_color', $storeId)
            ],
			'.footer .footer-container .footer-middle-content h1,.footer .footer-container .footer-middle-content h2,.footer .footer-container .footer-middle-content h3,.footer .footer-container .footer-middle-content h4,.footer .footer-container .footer-middle-content h5,.footer .footer-container .footer-middle-content h6' => [
                'color' => $this->getStoreConfig('color/footer/middle_heading_color', $storeId)
            ],
			'.footer .footer-container .footer-middle-content a' => [
                'color' => $this->getStoreConfig('color/footer/middle_link_color', $storeId)
            ],
			'.footer .footer-container .footer-middle-content a:hover,.footer .footer-container .footer-middle-content a:focus' => [
                'color' => $this->getStoreConfig('color/footer/middle_link_color_hover', $storeId)
            ],
			/* Bottom Footer Section */
            '.footer .footer-container .footer-bottom-content' => [
                'background-color' => $this->getStoreConfig('color/footer/bottom_background_color', $storeId),
                'color' => $this->getStoreConfig('color/footer/bottom_text_color', $storeId),
                'border-color' => $this->getStoreConfig('color/footer/bottom_border_color', $storeId)
            ],
			'.footer .footer-container .footer-bottom-content h5' => [
				'color' => $this->getStoreConfig('color/footer/bottom_text_color', $storeId)
			],
			'.footer .footer-container .footer-bottom-content h1,.footer .footer-container .footer-bottom-content h2,.footer .footer-container .footer-bottom-content h3,.footer .footer-container .footer-bottom-content h4,.footer .footer-container .footer-bottom-content h6' => [
                'color' => $this->getStoreConfig('color/footer/bottom_heading_color', $storeId)
            ],
			'.footer .footer-container .footer-bottom-content a' => [
                'color' => $this->getStoreConfig('color/footer/bottom_link_color', $storeId)
            ],
			'.footer .footer-container .footer-bottom-content a:hover,.footer .footer-container .footer-bottom-content a:focus' => [
                'color' => $this->getStoreConfig('color/footer/bottom_link_color_hover', $storeId)
            ],
			/* Newsletter Footer Section */
			'.footer .footer-container .footer-newsletter' => [
                'background-color' => $this->getStoreConfig('color/footer/footer_newsletter_background_color', $storeId),
				'color' => $this->getStoreConfig('color/footer/footer_newsletter_text_color', $storeId),
            ],
			'.footer .footer-container .footer-newsletter .title' => [
                'color' => $this->getStoreConfig('color/footer/footer_newsletter_text_color', $storeId),
            ],
        ];
        $setting = array_filter($setting);
        return $setting;
    }
	
	public function getClassLayoutProduct($layout){
		$class = '';
		 switch ($layout) {            
            case 'layout_productv1':
                $class = 'product-v1';
                break;
			case 'layout_productv2':
				$class = 'product-v2';
				break;
			case 'layout_productv3': 
				$class = 'product-v3';
				break;
			case 'layout_productv4':
				$class = 'product-v4';
				break;
			case 'layout_productv5':
				$class = 'product-v5';
        }
		return $class;
		
	}
	public function checkLayoutPage($category) {
		$settings = $this->_catalogDesign->getDesignSettings($category);		
		return $settings;
	}
}